 pref("network.protocol-handler.app.http","/usr/bin/firefox");
pref("network.protocol-handler.app.https","/usr/bin/firefox");
pref("extensions.tiny.serverurl", "http://localhost");
pref("extensions.tiny.serverport", "8069");
pref("extensions.tiny.webserverurl", "http://localhost:8080");
pref("extensions.tiny.webserverport", "8080");
pref("extensions.tiny.serverdbname", "terp");
pref("extensions.tiny.username","admin");
pref("extensions.tiny.password","admin");
pref("extensions.tiny.senderemail","");
pref("extensions.tiny.sendername","");
pref("extensions.tiny.statutdoc","");// add to have a statut to hidde or not the button
pref("extensions.tiny.message_label","");// add to message in push dialog
pref("extensions.tiny.receiveremail","");
pref("extensions.tiny.subject","");
pref("extensions.tiny.receiveddate","");
pref("extensions.tiny.partnerid","");
pref("extensions.tiny.contactid","");
pref("extensions.tiny.attachvalue","");
pref("extensions.tiny.cclist","");
pref("extensions.tiny.messagebody","");
pref("extensions.tiny.displayName","");
pref("extensions.tiny.attachmentdata","");
pref("extensions.tiny.userid",3);
pref("extensions.tiny.partnername","");
pref("extensions.tiny.officeno","");
pref("extensions.tiny.phoneno","");
pref("extensions.tiny.address","");
pref("extensions.tiny.listobject","Partner,Account Invoice,Product,Sale Order,Lead and opportunities");
pref("extensions.tiny.object","res.partner,account.invoice,product.product,sale.order,crm.lead");
pref("extensions.tiny.imagename","chrome://openerp_plugin/skin/Partner.png,chrome://openerp_plugin/skin/Invoice.png,chrome://openerp_plugin/skin/Product.png,chrome://openerp_plugin/skin/Sale.png,chrome://openerp_plugin/skin/Case.png");
pref("extensions.tiny.attachmentlength","");
pref("extensions.tiny.attachment","");
pref("extensions.tiny.db_list","false");
pref("extensions.tiny.connect_server","false");
pref("extensions.tiny.module_install","yes");
pref("extensions.tiny.serverprotocol", "false");



pref("mboximport.export.filenames_toascii", false);
pref("mboximport.export.overwrite", false);
pref("mboximport.confirm.before_mbox_import", true);
pref("mboximport.clipboard.always_just_text", false);
pref("mboximport.export.HTML_as_displayed", false);
pref("mboximport.exportEML.filename_format", 0);
pref("mboximport.delay.clean_statusbar", 5000);
pref("mboximport.subject.max_length", 50);
pref("mboximport.author.max_length", 50);
pref("mboximport.recipients.max_length", 50);
pref("extensions.{3ed8cc52-86fc-4613-9026-c1ef969da4c3}.description", "chrome://mboximport/locale/mboximport.properties");
pref("mboximport.export.set_filetime", false);
pref("mboximport.exportEML.use_dir", false);
pref("mboximport.exportMBOX.use_dir", false);
pref("mboximport.exportMSG.use_dir", false);
pref("mboximport.export.filenames_addtime", false);
pref("mboximport.export_all.warning1", true);
pref("mboximport.export_all.warning2", true);

pref("mboximport.exportMSG.dir", "/tmp");
//For debug in console
pref("browser.dom.window.dump.enabled", true);

