#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `plugin_thunderbird` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-plugin-thunderbird",
    version = "7.0.406",
    description = "Thunderbird Plug-In",
    long_description = 
"""

This module is required for the Thuderbird Plug-in to work properly.
====================================================================

The plugin allows you archive email and its attachments to the selected
OpenERP objects. You can select a partner, a task, a project, an analytical
account, or any other object and attach the selected mail as a .eml file in
the attachment of a selected record. You can create documents for CRM Lead,
HR Applicant and Project Issue from selected mails.
      
""",
    url = "http://www.openerp.com/",
    author = "",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.plugin_thunderbird': ".",
    },
    packages = ["openerp.addons.plugin_thunderbird"],
    package_data = {
        'openerp.addons.plugin_thunderbird': ["i18n/*.po*","plugin_thunderbird.xml","images/config_thunderbird.jpeg","images/config_thunderbird_plugin.jpeg","images/thunderbird_document.jpeg","static/thunderbird_plugin/install.js","static/thunderbird_plugin/chrome/openerp_plugin/skin/tinyerp-icon.ico","static/thunderbird_plugin/chrome/openerp_plugin/skin/developped_by.png","static/thunderbird_plugin/chrome/openerp_plugin/skin/Move.gif","static/thunderbird_plugin/chrome/openerp_plugin/skin/Archive.png","static/thunderbird_plugin/chrome/openerp_plugin/skin/MoveDown.png","static/thunderbird_plugin/chrome/openerp_plugin/skin/Create.png","static/thunderbird_plugin/chrome/openerp_plugin/skin/perform.gif","static/thunderbird_plugin/chrome/openerp_plugin/skin/logo.png","static/thunderbird_plugin/chrome/openerp_plugin/skin/Error.gif","static/thunderbird_plugin/chrome/openerp_plugin/skin/Search.gif","static/thunderbird_plugin/chrome/openerp_plugin/skin/settings.png","static/thunderbird_plugin/chrome/openerp_plugin/skin/MoveLeft.png","static/thunderbird_plugin/chrome/openerp_plugin/skin/openerp.png","static/thunderbird_plugin/chrome/openerp_plugin/skin/Success.gif","static/thunderbird_plugin/chrome/openerp_plugin/content/js/dialog.js","static/thunderbird_plugin/chrome/openerp_plugin/content/js/create.js","static/thunderbird_plugin/chrome/openerp_plugin/content/js/config.js","static/thunderbird_plugin/chrome/openerp_plugin/content/js/push.js","static/thunderbird_plugin/chrome/openerp_plugin/content/js/tiny_xmlrpc.js","static/thunderbird_plugin/chrome/openerp_plugin/content/js/tools.js","static/thunderbird_plugin/chrome/openerp_plugin/content/js/overlay.js","static/thunderbird_plugin/defaults/preferences/tiny.js","static/thunderbird_plugin/components/nsXmlRpcClient.js","i18n/sk.po","i18n/hr.po","i18n/da.po","i18n/sl.po","i18n/ru.po","i18n/en_GB.po","i18n/cs.po","i18n/fi.po","i18n/pt_BR.po","i18n/bg.po","i18n/ja.po","i18n/ro.po","i18n/sr@latin.po","i18n/es.po","i18n/mn.po","i18n/it.po","i18n/nl.po","i18n/sv.po","i18n/tr.po","i18n/de.po","i18n/et.po","i18n/is.po","i18n/sr.po","i18n/hu.po","i18n/eu.po","i18n/en_US.po","i18n/gl.po","i18n/mk.po","i18n/ca.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/nb.po","i18n/ar.po","i18n/pt.po","i18n/es_CR.po","plugin_thunderbird.xml"],
    },
    install_requires = ["openerp-core","openerp-mail","openerp-plugin"],
    tests_require = ["unittest2"],
)
